@@ -1,4 +1,5 @@
 import json
+from django.conf import settings
 from typing import Union
 
 
@@ -17,6 +18,23 @@ def get_http_referer(request):
     return http_referer if http_referer else http_host
 
 
+def allowed_ip(request):
+    user_ip = get_ip(request)
+
+    for allow_ip in settings.ALLOWED_IP:
+        if user_ip == allow_ip or user_ip.startswith(allow_ip):
+            return True
+    return False
+
+
+def fix_flow_signal(func):
+    def _wrapper_fix_signal(self, **kwargs):
+        kwargs.update({'self': self})
+        func(**kwargs)
+
+    return _wrapper_fix_signal
+
+
 def write_cloud_functions_log(message: Union[str, dict], severity: str = 'DEBUG', request_=None,
                               project: str = 'expressmoney'):
     """ Запись структурированных логов в Cloud Functions logger """
